@@ -1,7 +1,7 @@
+import sys
 
 from django.core.management.base import AppCommand, CommandError
 from drf_generators.generators import *
-from optparse import make_option
 import django
 
 
@@ -10,32 +10,35 @@ class Command(AppCommand):
 
     args = "[appname ...]"
 
-    base_options = (
-        make_option('-f', '--format', dest='format', default='viewset',
-                    help='view format (default: viewset)'),
+    def add_arguments(self, parser):
+        super(Command, self).add_arguments(parser)
+        parser.add_argument('-f', '--format', dest='format',
+                            default='viewset',
+                            help='view format (default: viewset)'),
 
-        make_option('-d', '--depth', dest='depth', default=0,
-                    help='serialization depth'),
+        parser.add_argument('-d', '--depth', dest='depth', default=0,
+                            help='serialization depth'),
 
-        make_option('--force', dest='force', action='store_true',
-                    help='force overwrite files'),
+        parser.add_argument('--force', dest='force', action='store_true',
+                            help='force overwrite files'),
 
-        make_option('--serializers', dest='serializers', action='store_true',
-                    help='generate serializers only'),
+        parser.add_argument('--serializers', dest='serializers',
+                            action='store_true',
+                            help='generate serializers only'),
 
-        make_option('--views', dest='views', action='store_true',
-                    help='generate views only'),
+        parser.add_argument('--views', dest='views', action='store_true',
+                            help='generate views only'),
 
-        make_option('--urls', dest='urls', action='store_true',
-                    help='generate urls only'),
-    )
-
-    option_list = AppCommand.option_list + base_options
+        parser.add_argument('--urls', dest='urls', action='store_true',
+                            help='generate urls only'),
 
     def handle_app_config(self, app_config, **options):
         if app_config.models_module is None:
             raise CommandError('You must provide an app to generate an API')
 
+        if sys.version_info[0] != 3 or sys.version_info[1] < 4:
+            raise CommandError('Python 3.4 or newer is required')
+
         if django.VERSION[1] == 7:
             force = options['force'] if 'force' in options else False
             format = options['format'] if 'format' in options else None
@@ -47,7 +50,7 @@ class Command(AppCommand):
             views = options['views'] if 'views' in options else False
             urls = options['urls'] if 'urls' in options else False
 
-        elif django.VERSION[1] >= 8:
+        elif django.VERSION[1] >= 8 or django.VERSION[0] == 2:
             force = options['force']
             format = options['format']
             depth = options['depth']
